AsLua

Trait AsLua 

pub unsafe trait AsLua<'lua> {
    // Required method
    fn as_lua(&self) -> LuaContext;
}
Trait for objects that have access to a Lua context. When using a context returned by a AsLua, you are not allowed to modify the stack.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, 'lua, L> AsLua<'lua> for &'a L
where L: AsLua<'lua> + ?Sized,

Source

impl<'a, 'lua, L> AsLua<'lua> for &'a mut L
where L: AsLua<'lua> + ?Sized,

Implementors

Source

impl<'a, 'lua> AsLua<'lua> for &'a InsideCallback

Source

impl<'a, 'lua> AsLua<'lua> for &'a mut InsideCallback

Source

impl<'a, 'lua> AsLua<'lua> for Lua<'lua>

Source

impl<'lua, L> AsLua<'lua> for LuaFunction<L>
where L: AsLua<'lua>,

Source

impl<'lua, L> AsLua<'lua> for LuaTable<L>
where L: AsLua<'lua>,

Source

impl<'lua, L> AsLua<'lua> for PushGuard<L>
where L: AsMutLua<'lua>,

Source

impl<'lua, T, L> AsLua<'lua> for UserdataOnStack<T, L>
where L: AsLua<'lua>, T: 'lua + Any,

Source

impl<'t, 'lua, L, K, V> AsLua<'lua> for LuaTableIterator<'t, L, K, V>
where L: AsMutLua<'lua>,