pub unsafe trait AsMutLua<'lua>: AsLua<'lua> {
// Required method
fn as_mut_lua(&mut self) -> LuaContext;
}Expand description
Trait for objects that have access to a Lua context. You are allowed to modify the stack, but it must be in the same state as it was when you started.
Required Methods
Sourcefn as_mut_lua(&mut self) -> LuaContext
fn as_mut_lua(&mut self) -> LuaContext
Returns the raw Lua context.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".