pub unsafe trait AsLua<'lua> {
// Required method
fn as_lua(&self) -> LuaContext;
}Expand description
Trait for objects that have access to a Lua context. When using a context returned by a
AsLua, you are not allowed to modify the stack.
Required Methods
fn as_lua(&self) -> LuaContext
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".